import fastlabel

client = fastlabel.Client()

project_slug = "YOUR_PROJECT_SLUG"
tasks = client.get_image_tasks(project=project_slug)
annotations = client.get_annotations(project=project_slug)

client.export_coco(
    project=project_slug,
    tasks=tasks,
    annotations=annotations,
    output_dir="./export_coco/",
)



from pprint import pprint

import fastlabel

client = fastlabel.Client()

auto_annotation_job = client.execute_auto_annotation_job(
    project="YOUR_PROJECT_SLUG",
    model_name="MODEL_NAME",
)
pprint(auto_annotation_job)



import fastlabel

client = fastlabel.Client()

project_slug = "YOUR_PROJECT_SLUG"
tasks = client.get_image_tasks(project=project_slug)

client.export_yolo(project=project_slug, tasks=tasks, output_dir="./export_yolo/")



import glob
import os
import time

import fastlabel

client = fastlabel.Client()

project = "YOUR_PROJECT_SLUG"

input_file_path = "./classes.txt"
input_dataset_path = "./dataset/"
annotations_map = client.convert_yolo_to_fastlabel(
    classes_file_path=input_file_path,
    dataset_folder_path=input_dataset_path,
    project_type="segmentation",
)
for image_file_path in glob.iglob(
    os.path.join(input_dataset_path, "**/**.jpg"), recursive=True
):
    time.sleep(1)
    name = image_file_path.replace(os.path.join(*[input_dataset_path, ""]), "")
    file_path = image_file_path
    annotations = (
        annotations_map.get(name) if annotations_map.get(name) is not None else []
    )
    task_id = client.create_image_task(
        project=project, name=name, file_path=file_path, annotations=annotations
    )
